@@ -63,6 +63,7 @@
 #include "util/logging.h"
 #include "fderead.h"
 #include "symbol.h"
+#include "../config.h"
 
 //the ELF file is always opened read-only. If you want to write a copy
 //to disk, call writeOutElf. 
@@ -84,6 +85,23 @@ ElfInfo* openELFFile(char* fname)
     free(e);
     return NULL;
   }
+  size_t nbytes;
+  char* identBytes=elf_getident(e->e,&nbytes);
+  switch(identBytes[EI_CLASS])
+  {
+  case ELFCLASS32:
+    #ifdef KATANA_X86_64_ARCH
+    logprintf(ELL_WARN,ELS_MISC,"This is a 64-bit version of katana but you are trying to work with a 32-bit ELF file. No testing or attempt to ensure correctness has been made for this case. You will probably do better compiling a 32-bit version of katana. If this feature is important to you, please send email to"PACKAGE_BUGREPORT"\n");
+    #endif
+    break;
+  case ELFCLASS64:
+#ifdef KATANA_X86_ARCH
+    logprintf(ELL_WARN,ELS_MISC,"This is a 32-bit version of katana but you are trying to work with a 64-bit ELF file. No testing or attempt to ensure correctness has been made for this case. You will probably do better compiling a 32-bit version of katana. If this feature is important to you, please send email to"PACKAGE_BUGREPORT"\n");
+#endif
+    break;
+  default:
+    logprintf(ELL_WARN,ELS_MISC,"Unrecognized ELF class, results may not be what you want");
+  }
   findELFSections(e);
   return e;
 }
@@ -191,6 +209,7 @@ ElfInfo* duplicateElf(ElfInfo* e,char* outfname,bool flushToDisk,bool keepLayout
   if (elf_update(outelf, flushToDisk?ELF_C_WRITE:ELF_C_NULL) <0)
   {
     fprintf(stdout,"Failed to write out elf file: %s\n",elf_errmsg (-1));
+    return NULL;
   }
   ElfInfo* newE=zmalloc(sizeof(ElfInfo));
   newE->dataAllocatedByKatana=true;
