@@ -130,6 +130,18 @@ int addStrtabEntry(ElfInfo* e,char* str)
   return strtab_data->d_size-len;
 }
 
+//adds an entry to the section header string table, return its offset
+int addShdrStrtabEntry(ElfInfo* e,char* str)
+{
+  Elf_Scn* scn=elf_getscn(e->e,e->sectionHdrStrTblIdx);
+  assert(scn);
+  Elf_Data* data=elf_getdata(scn,NULL);
+  int len=strlen(str)+1;
+  addDataToScn(data,str,len);
+  elf_flagdata(data,ELF_C_SET,ELF_F_DIRTY);
+  return data->d_size-len;
+}
+
 //return index of entry in symbol table
 int addSymtabEntry(ElfInfo* e,Elf_Data* data,ElfXX_Sym* sym)
 {
@@ -363,7 +375,9 @@ ElfInfo* startPatchElf(FILE* file,char* filename)
 
   createSections(patch);
   ehdr->e_shstrndx=elf_ndxscn(getSectionByERS(patch,ERS_STRTAB));//set strtab in elf header
-  //todo: perhaps the two string tables should be separate
+  //todo: perhaps the two string tables should be separate. ELF
+  //normally does this, but using only the one has worked ok for me so
+  //far. I should look into it.
   patch->strTblIdx=patch->sectionHdrStrTblIdx=ehdr->e_shstrndx;
   return patch;
 }
@@ -402,7 +416,8 @@ void finalizeDataSizes(ElfInfo* e)
       int overlap=(lastShdr->sh_addr+lastShdr->sh_size)-shdr->sh_addr;
       if(overlap>1)
       {
-        death("When loaded into memory, sections '%s' and '%s' (at addressex 0x%x and 0x%x respectively) in ELF file %s overlap by %i bytes, presumably from the first section expanding. Katana should be capable of resizing appropriately (although with some difficulty when relocations are involved and the binary has not been linked with --emit-relocs) but this feature has not yet been implemented\n",getScnHdrString(e,lastShdr->sh_name),getScnHdrString(e,shdr->sh_name),lastShdr->sh_addr,shdr->sh_addr,e->fname,overlap);
+        death("When loaded into memory, sections '%s' and '%s' (at addressex 0x%x and 0x%x respectively) in ELF file %s overlap by %i bytes, presumably from the first section expanding to %#zx bytes. Katana should be capable of resizing appropriately (although with some difficulty when relocations are involved and the binary has not been linked with --emit-relocs) but this feature has not yet been implemented\n",getScnHdrString(e,lastShdr->sh_name),getScnHdrString(e,shdr->sh_name),
+              lastShdr->sh_addr,shdr->sh_addr,e->fname,overlap,lastShdr->sh_size);
       }
     }
     if(shdr->sh_flags & SHF_ALLOC)
@@ -467,6 +482,7 @@ int reindexSectionForPatch(ElfInfo* e,int scnIdx,ElfInfo* patch)
       GElf_Shdr shdr;
       getShdr(scn,&shdr);
       patchScn=elf_newscn(patch->e);
+      elf_newdata(patchScn);//libelf seems to get pissy if a section doesn't have any data, I'm not quite sure why
       ElfXX_Shdr* patchShdr=elfxx_getshdr(patchScn);
       patchShdr->sh_type=shdr.sh_type;
       patchShdr->sh_link=shdr.sh_link;
