@@ -309,7 +309,6 @@ DwarfExpr parseDwarfExpression(byte* data,uint len)
     default:
       death("Unsupported DW_OP with code 0x%x\n",instr->type);
     }
-    printExprInstruction(stdout,"adding instruction ",*instr,0);
   }
 
   result.instructions=realloc(result.instructions,sizeof(DwarfExprInstr)*result.numInstructions);
@@ -334,6 +333,7 @@ RegInstruction* parseFDEInstructions(Dwarf_Debug dbg,unsigned char* bytes,
     int high = byte & 0xc0;
     int low = byte & 0x3f;
     short unsigned int uleblen;
+    uint exprBytesLen;
     result[*numInstrs].arg1Reg.type=ERT_NONE;//not using reg unless we set its type
     result[*numInstrs].arg2Reg.type=ERT_NONE;//not using reg unless we set its type
     switch(high)
@@ -388,11 +388,11 @@ RegInstruction* parseFDEInstructions(Dwarf_Debug dbg,unsigned char* bytes,
           len -= 4;
         }
         break;
+      case DW_CFA_undefined:
       case DW_CFA_same_value:
-        result[*numInstrs].type=high;
-        result[*numInstrs].arg1=low;
-        result[*numInstrs].arg1Reg.type=ERT_BASIC;
-        result[*numInstrs].arg1Reg.u.index=low;
+        result[*numInstrs].arg1Reg=readRegFromLEB128(bytes + 1,&uleblen);
+        bytes+=uleblen;
+        len-=uleblen;
         break;
       case DW_CFA_register:
         result[*numInstrs].arg1Reg=readRegFromLEB128(bytes + 1,&uleblen);
@@ -457,7 +457,15 @@ RegInstruction* parseFDEInstructions(Dwarf_Debug dbg,unsigned char* bytes,
         result[*numInstrs].arg1Reg=readRegFromLEB128(bytes + 1,&uleblen);
         bytes+=uleblen;
         len-=uleblen;
-        uint exprBytesLen=leb128ToUInt(bytes + 1, &uleblen);
+        exprBytesLen=leb128ToUInt(bytes + 1, &uleblen);
+        bytes+=uleblen;
+        len-=uleblen;
+        result[*numInstrs].expr=parseDwarfExpression(bytes+1,exprBytesLen);
+        bytes+=exprBytesLen;
+        len-=exprBytesLen;
+        break;
+      case DW_CFA_def_cfa_expression:
+        exprBytesLen=leb128ToUInt(bytes + 1, &uleblen);
         bytes+=uleblen;
         len-=uleblen;
         result[*numInstrs].expr=parseDwarfExpression(bytes+1,exprBytesLen);
@@ -490,6 +498,7 @@ int fdeCmp(const void* a,const void* b)
 //the DW_AT_MIPS_fde attribute of the relevant type) and the FDE
 //structure.  if ehInsteadOfDebug is true, then read information from
 //.eh_frame instead of .debug_frame.
+//return NULL on error
 Map* readDebugFrame(ElfInfo* elf,bool ehInsteadOfDebug)
 {
   Dwarf_Fde *fdeData = NULL;
@@ -501,6 +510,7 @@ Map* readDebugFrame(ElfInfo* elf,bool ehInsteadOfDebug)
   Dwarf_Error err;
   Dwarf_Debug dbg;
   addr_t* lsdaPointers=NULL;
+  int numLSDAPointers=0;
   if(DW_DLV_OK!=dwarf_elf_init(elf->e,DW_DLC_READ,&dwarfErrorHandler,NULL,&dbg,&err))
   {
     dwarfErrorHandler(err,NULL);
@@ -526,22 +536,22 @@ Map* readDebugFrame(ElfInfo* elf,bool ehInsteadOfDebug)
     }
     scn=getSectionByName(elf,".eh_frame");
     Elf_Scn* hdrScn=getSectionByName(elf,".eh_frame_hdr");
+    if(!hdrScn)
+    {
+      logprintf(ELL_WARN,ELS_DWARF_FRAME,"ELF has no .eh_frame_hdr section, unable to read frame\n");
+      return NULL;
+    }
     GElf_Shdr shdr;
     getShdr(hdrScn,&shdr);
     elf->callFrameInfo.ehHdrAddress=shdr.sh_addr;
-    Elf_Scn* exceptTableSection=getSectionByName(elf,".gcc_except_table");
-    if(exceptTableSection)
-    {
-      getShdr(exceptTableSection,&shdr);
-      elf->callFrameInfo.exceptTableAddress=shdr.sh_addr;
-      ExceptTable et=parseExceptFrame(exceptTableSection,&lsdaPointers);
-      elf->callFrameInfo.exceptTable=zmalloc(sizeof(ExceptTable));
-      memcpy(elf->callFrameInfo.exceptTable,&et,sizeof(et));
-    }
+
+    //get the encoding value
+    Elf_Data* hdrData=elf_getdata(hdrScn,NULL);
+    elf->callFrameInfo.hdrTableEncoding=((byte*)hdrData->d_buf)[3];
   }
   GElf_Shdr shdr;
   getShdr(scn,&shdr);
-  elf->callFrameInfo.sectionAddress=shdr.sh_addr;
+  elf->callFrameInfo.ehAddress=shdr.sh_addr;
     
 
   //read the CIE
@@ -582,7 +592,7 @@ Map* readDebugFrame(ElfInfo* elf,bool ehInsteadOfDebug)
     //doing pc-relative pointer encodings) is a bit of a pain.
     Dwarf_Off cieOff;
     dwarf_cie_section_offset(dbg,cieData[i],&cieOff,&err);
-    addr_t cieAddress=elf->callFrameInfo.sectionAddress+cieOff;
+    addr_t cieAddress=elf->callFrameInfo.ehAddress+cieOff;
     //ok, now we have the address of the cie. We want the offset to
     //the augmentation todo: the below sizes are all for 32-bit DWARF
     //format, not 64-bit.  (32-bit DWARF format is still most
@@ -707,9 +717,9 @@ Map* readDebugFrame(ElfInfo* elf,bool ehInsteadOfDebug)
         }
       }
       //turn the offset into an address
-      addr_t augDataAddr=elf->callFrameInfo.sectionAddress+augDataOffset;
+      addr_t augDataAddr=elf->callFrameInfo.ehAddress+augDataOffset;
       parseFDEAugmentationData(elf->callFrameInfo.fdes+i,augDataAddr,
-                               augdata,augdataLen,lsdaPointers,elf->callFrameInfo.exceptTable->numLSDAs);
+                               augdata,augdataLen,&lsdaPointers,&numLSDAPointers);
     }
     
     int* key=zmalloc(sizeof(int));
@@ -718,6 +728,19 @@ Map* readDebugFrame(ElfInfo* elf,bool ehInsteadOfDebug)
     dwarf_dealloc(dbg,dfde,DW_DLA_FDE);
   }
 
+  if(ehInsteadOfDebug)
+  {
+    Elf_Scn* exceptTableSection=getSectionByName(elf,".gcc_except_table");
+    if(exceptTableSection)
+    {
+      getShdr(exceptTableSection,&shdr);
+      elf->callFrameInfo.exceptTableAddress=shdr.sh_addr;
+      ExceptTable et=parseExceptFrame(exceptTableSection,lsdaPointers,numLSDAPointers);
+      elf->callFrameInfo.exceptTable=zmalloc(sizeof(ExceptTable));
+      memcpy(elf->callFrameInfo.exceptTable,&et,sizeof(et));
+    }
+  }
+
   //sort fdes by lowpc unless this is a patch object. This
   //makes determining backtraces easier
   qsort(elf->callFrameInfo.fdes,elf->callFrameInfo.numFDEs,sizeof(FDE),fdeCmp);
