@@ -750,8 +750,16 @@ ElfInfo* createPatch(char* oldSourceTree,char* newSourceTree,char* oldBinName,ch
     }
   }
   newBinary=openELFFile(newBinName);
+  if(!newBinary)
+  {
+    death("Could not create patch because could not open new binary\n");
+  }
   findELFSections(newBinary);
   oldBinary=openELFFile(oldBinName);
+  if(!oldBinary)
+  {
+    death("Could not create patch because could not open old binary\n");
+  }
   findELFSections(oldBinary);
   patch=startPatchElf(patchOutfile,filename);
   Dwarf_Error err;
@@ -854,7 +862,7 @@ ElfInfo* createPatch(char* oldSourceTree,char* newSourceTree,char* oldBinName,ch
 
   if(elf_update (patch->e, ELF_C_WRITE) <0)
   {
-    death("Failed to write out elf file: %s\n",elf_errmsg (-1));
+    death("Failed to write out elf file %s: %s\n",patch->fname,elf_errmsg (-1));
     exit(1);
   }
   return patch;
