@@ -119,7 +119,8 @@ typedef enum
   ERRT_CFA,
   ERRT_EXPR,
   ERRT_RECURSE_FIXUP,
-  ERRT_RECURSE_FIXUP_POINTER
+  ERRT_RECURSE_FIXUP_POINTER,
+  ERRT_UNDEFINED
 } E_REG_RULE_TYPE;
 
 typedef struct
