@@ -60,7 +60,7 @@
 #include "util/dictionary.h"
 #include "util/map.h"
 #include "util/list.h"
-#include <libdwarf.h>
+#include "libdwarf_inc.h"
 #include <string.h>
 #include "util/refcounted.h"
 
